
%%% Chemical Espionage

% dP/dt = P a (1-mp) [ c E(mp) (1-W(a)) ] + P (1-mp)(1-a)[c E(mp)(1-H(mp)]
% mp = male proportion of butterfly
% a = proportion using anti-aphrodisiac
% W(a)  = wasp effect
% H(mp) = Male harassment
% E(mp) = Fertilization rate
% d = death rate
% c = clutch size
% b = related to carrying capacity
% W = B P  # of wasps is proportional to number of butterflies
function dP = Popode2(t, P, mp, a, d, c, b, B)

E = atan(mp)*(2/pi);
W = sqrt(a);
H = sqrt(mp);


dP = P *a* (1-mp)* ( c* E *(1-B*P) )+  ...
    P *(1-mp)*(1-a)*(c *E*(1-H)) - d*P -b*P.^2;
end

